==> angularjs-input-tags-0.1.0.tgz: package/docs/index.md <==
## Angular Tags Dropdown

An [AngularJS](https://angularjs.org/) [Component](https://docs.angularjs.org/guide/component) for tags input behaviour on the top of bootstrap

### Demo

<tags-dropdown tags="$ctrl.tags"
            suggestions="$ctrl.suggestions"
            key-property="code"
            display-property="title"
            min-length="1">
</tags-dropdown>

### Usage

Add module to your app:

```javascript
angular.module('app', ['angularjs-input-tags']);
```

And the component where you want in this app:

```html
<tags-dropdown tags="$sctrl.tags"
            suggestions="$ctrl.suggestions"
            key-property="code"
            display-property="title">
</tags-dropdown>
```

Fill data in a controller:

```javascript
angular.module('app').controller('SearchController', searchCtrl);

function searchCtrl() {
  const vm = this;
  
  vm.tags = [{
    code: 'default',
    title: 'root'
  }];

  vm.suggestions = {
    title: 'root',
    data: [{
      code: 1,
      title: '1',
      data: [/* Another nested list of items for multilevel purposes */]},
    ]
  };
}
```

### LICENCE MIT

The MIT License (MIT)

Copyright (c) 2017 HeyProf!

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> angularjs-input-tags-0.2.1.tgz: package/docs/index.md <==
## Install

- npm: `npm install --save angularjs-input-tags`
- bower: `bower install --save angularjs-input-tags`

## Demo

<input-tags tags="$ctrl.tags"
            suggestions="$ctrl.suggestions"
            key-property="code"
            display-property="title"
            min-length="1">
</input-tags>

## Usage

Add module to your app:

```javascript
angular.module('app', ['angularjs-input-tags']);
```

And the component where you want in this app:

```html
<input-tags tags="$sctrl.tags"
            suggestions="$ctrl.suggestions"
            key-property="code"
            display-property="title">
</input-tags>
```

Fill data in a controller:

```javascript
angular.module('app').controller('SearchController', searchCtrl);

function searchCtrl() {
  const vm = this;
  
  vm.tags = [{
    code: 'default',
    title: 'root'
  }];

  vm.suggestions = {
    title: 'root',
    data: [{
      code: 1,
      title: '1',
      data: [/* Another nested list of items for multilevel purposes */]},
    ]
  };
}
```

## LICENCE MIT

The MIT License (MIT)

Copyright (c) 2017 HeyProf!

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
